@@ -3,8 +3,9 @@ use 5.005;
 use warnings;
 use strict;
 use base 'DBIx::Class::Schema';
+use File::HomeDir;
 
-our $VERSION = '0.001006'; # 0.1.6
+our $VERSION = '0.001007'; # 0.1.7
 $VERSION = eval $VERSION;
 
 sub connection {
@@ -70,7 +71,7 @@ sub load_credentials {
 sub filter_loaded_credentials { $_[1] };
 
 __PACKAGE__->mk_classaccessor('config_paths'); 
-__PACKAGE__->config_paths([('./dbic', $ENV{HOME} . '/.dbic', '/etc/dbic')]);
+__PACKAGE__->config_paths([('./dbic', File::HomeDir->my_home . '/.dbic', '/etc/dbic')]);
 
 1;
 
@@ -94,7 +95,7 @@ be found at L<http://www.symkat.com/credential-management-in-dbix-class>
 
     /etc/dbic.yaml
     MY_DATABASE:
-        dsn: "rbi:Pg:host=localhost;database=blog"
+        dsn: "dbi:Pg:host=localhost;database=blog"
         user: "TheDoctor"
         password: "dnoPydoleM"
         TraceLevel: 1
@@ -182,8 +183,8 @@ eq B<USERNAME>.
 
 Additional parameters can be added by appending a hashref,
 to the connection call, as an example, C<-E<gt>connect( 'CONFIG', 
-{ hostname =E<lt> "db.foo.com" } );> will give C<$connect_args> a 
-structure like C<{ dsn =E<lt> 'CONFIG', hostname =E<lt> "db.foo.com" }>.
+{ hostname =E<gt> "db.foo.com" } );> will give C<$connect_args> a
+structure like C<{ dsn =E<gt> 'CONFIG', hostname =E<gt> "db.foo.com" }>.
 
 For instance, if you want to use hostnames when you make the
 initial connection to DBIC and are using the configuration primarily
@@ -277,14 +278,20 @@ SymKat I<E<lt>symkat@symkat.comE<gt>>
 
 =head1 CONTRIBUTORS
 
-mst: Matt S. Trout <mst@shadowcatsystems.co.uk>
+=over 4
 
-ribasushi: Peter Rabbitson <ribasushi@cpan.org>
+=item * Matt S. Trout (mst) I<E<lt>mst@shadowcat.co.ukE<gt>> 
+
+=item * Peter Rabbitson (ribasushi) I<E<li>ribasushi@cpan.orgE<GT>>
+
+=item * Christian Walde I<E<lt>walde.christian@googlemail.comE<gt>>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This is free software licensed under a I<BSD-Style> License.  Please see the 
-LICENSE file included in this package for more detailed information.
+This library is free software and may be distributed under the same terms 
+as perl itself.
 
 =head1 AVAILABILITY
 
